@@ -56,7 +56,20 @@ namespace PluginXine
     if (prevSettings.setupDiffers(m_globalSettings))
     {
       m_xineLib->execFuncSetup();
+#if APIVERSNUM >= 10707
+      bool lockOsdUpdate = prevSettings.OsdExtentParams() != m_globalSettings.OsdExtentParams();
+      if (lockOsdUpdate)
+      {
+        m_xineLib->LockOsdUpdate();
+        cOsdProvider::UpdateOsdSize(true);
+        SetDisplayMenu();
+        Display();
+      }
+
+      m_xineLib->ReshowCurrentOSD(lockOsdUpdate);
+#else
       m_xineLib->ReshowCurrentOSD();
+#endif
     }
     
     return state;
